"""Adapter for PySerial methods to Micropython machine.UART methods.

This module attempts to enable compatibility with microcontrollers running
Micropython.

"""
try:
    from serial import Serial
except ImportError:
    from machine import UART
    from .constants import BAUDRATES
    

    class SerialException(Exception):
        """Proxy error for PySerial mapping."""
    
    
    class SerialTimeoutException(SerialException):
        """Proxy error for PySerial mapping."""
    
    
    class Serial(UART):
        """Maps Micropython machine.UART to equivalent serial.Serial methods."""
        def __init__(self,
                    port: 'str|int|None',
                    baudrate: int = 9600,
                    bytesize: int = 8,
                    parity: str ='N',
                    stopbits: int = 1,
                    **kwargs) -> None:
            """"""
            if not isinstance(port, int):
                raise ValueError('Serial proxy must be an integer UART number')
            if baudrate not in BAUDRATES:
                raise ValueError(f'Baudrate must be in {BAUDRATES}')
            if parity == 'N':
                parity = None
            elif parity == 'E':
                parity = 0
            elif parity == 'O':
                parity = 1
            else:
                raise ValueError('Supported parities N, E, O')
            if bytesize not in [8]:
                raise ValueError('Invalid bytesize must be 8')
            if stopbits not in [1]:
                raise ValueError('Invalid stopbits must be 1')
            super().__init__(port, baudrate)
            init_kwargs = {}
            for k, v in kwargs.items():
                if k in ['tx', 'rx', 'timeout', 'timeout_char']:
                    init_kwargs[k] = v
                elif k == 'inter_byte_timeout':
                    init_kwargs['timout_char'] = v
            super().init(baudrate=baudrate, bits=bytesize, parity=parity,
                         stop=stopbits, **init_kwargs)
        
        def open(self) -> None:
            """Open port with current settings.
            
            *Not required* - opened automatically on creation.
            This may throw a SerialException if the port cannot be opened.
            
            """
            pass
        
        def close(self) -> None:
            """Close port.
            
            *Not required* - closed automatically on destruction.
            
            """
            pass
        
        @property
        def in_waiting(self) -> int:
            """Return the number of bytes currently in the input buffer."""
            return super().any()

        def read(self, size: int = 1) -> bytes:
            """Read size bytes from the serial port.
            
            If a timeout is set it may return less characters than requested.
            With no timeout it will block until the requested number of bytes
            is read.
            """
            return super().read(size)
        
        def write(self, data: bytes) -> int:
            """Output the given bytes/buffer over the serial port."""
            written = super().write(data)
            if written is None:
                raise SerialTimeoutException
            return written



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pynimomodem']

package_data = \
{'': ['*']}

install_requires = \
['pyserial>=3.5,<4.0']

setup_kwargs = {
    'name': 'pynimomodem',
    'version': '0.1.1',
    'description': "A Python implementation of Viasat's NIMO modem interface project.",
    'long_description': '# pynimomodem\n\nA Python implementation of the [Viasat](www.viasat.com)\nNIMO modem interface for satellite IoT.\n\nNIMO stands for **Non-IP Modem Orbcomm** waveform\nand represents a family of low cost satellite data modems that use network\nprotocols developed by [ORBCOMM](www.orbcomm.com)\nincluding [IsatData Pro](https://www.inmarsat.com/en/solutions-services/enterprise/services/isatdata-pro.html) and its successor, OGx.\n\nThese ORBCOMM protocols can operate over the Viasat L-band global network in\ncooperation with a varietry of authorized Viasat IoT service partners, and\nare intended for event-based remote data collection and device control.\n\nExample NIMO modems available:\n* [ORBCOMM ST2100](https://www.orbcomm.com/en/partners/iot-hardware/st-2100)\n* [Quectel CC200A-LB](https://www.quectel.com/product/cc200a-lb-satellite-communication-module)\n* [uBlox UBX-S52](https://content.u-blox.com/sites/default/files/documents/UBX-R52-S52_ProductSummary_UBX-19026227.pdf)',
    'author': 'geoffbrucepayne',
    'author_email': 'geoff.bruce-payne@inmarsat.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/inmarsat-enterprise/pynimomodem',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
